@@ -17,125 +17,131 @@
 import os
 import stat
 import subprocess
-import sys
-import stat
 
+from keystone.common import logging
 from keystone import config
 
 
+LOG = logging.getLogger(__name__)
 CONF = config.CONF
-DIR_PERMS = stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR | \
-    stat.S_IRGRP | stat.S_IXGRP | \
-    stat.S_IROTH | stat.S_IXOTH
+DIR_PERMS = (stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR |
+             stat.S_IRGRP | stat.S_IXGRP |
+             stat.S_IROTH | stat.S_IXOTH)
 CERT_PERMS = stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH
 PRIV_PERMS = stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR
-DEFAULT_SUBJECT = "/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com"
+DEFAULT_SUBJECT = '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com'
 
 
 def file_exists(file_path):
-    sys.stdout.write("Looking for %s:\t" % file_path)
-    if os.path.exists(file_path):
-        print("[FOUND]")
-        return True
-    else:
-        print("[NOT FOUND]")
-        return False
-
-
-def make_dirs(file_name):
-    dir = os.path.dirname(file_name)
-    if not file_exists(dir):
-        os.makedirs(dir, DIR_PERMS)
+    return os.path.exists(file_path)
 
 
 class ConfigurePKI(object):
-    """Generate files for PKI siginging using OpenSSL
+    """Generate files for PKI signing using OpenSSL.
 
     Signed tokens require a private key and signing certificate which itself
     must be signed by a CA.  This class generates them with workable defaults
     if each of the files are not present
+
     """
-    def __init__(self, *args, **kw):
+
+    def __init__(self, keystone_user, keystone_group, **kw):
         self.conf_dir = os.path.dirname(CONF.signing.ca_certs)
+        self.use_keystone_user = keystone_user
+        self.use_keystone_group = keystone_group
         self.ssl_config_file_name = os.path.join(self.conf_dir, "openssl.conf")
         self.ca_key_file = os.path.join(self.conf_dir, "cakey.pem")
         self.request_file_name = os.path.join(self.conf_dir, "req.pem")
         self.ssl_dictionary = {'conf_dir': self.conf_dir,
-                               "ca_cert": CONF.signing.ca_certs,
-                               "ssl_config": self.ssl_config_file_name,
-                               "ca_private_key": self.ca_key_file,
-                               "ca_cert_cn": "hostname",
-                               "request_file": self.request_file_name,
-                               "signing_key": CONF.signing.keyfile,
-                               "signing_cert": CONF.signing.certfile,
-                               "default_subject": DEFAULT_SUBJECT,
-                               "key_size": int(CONF.signing.key_size),
-                               "valid_days": int(CONF.signing.valid_days),
-                               "ca_password": CONF.signing.ca_password}
+                               'ca_cert': CONF.signing.ca_certs,
+                               'ssl_config': self.ssl_config_file_name,
+                               'ca_private_key': self.ca_key_file,
+                               'ca_cert_cn': 'hostname',
+                               'request_file': self.request_file_name,
+                               'signing_key': CONF.signing.keyfile,
+                               'signing_cert': CONF.signing.certfile,
+                               'default_subject': DEFAULT_SUBJECT,
+                               'key_size': int(CONF.signing.key_size),
+                               'valid_days': int(CONF.signing.valid_days),
+                               'ca_password': CONF.signing.ca_password}
+
+    def _make_dirs(self, file_name):
+        dir = os.path.dirname(file_name)
+        if not file_exists(dir):
+            os.makedirs(dir, DIR_PERMS)
+        if os.geteuid() == 0 and self.use_keystone_group:
+            os.chown(dir, -1, self.use_keystone_group)
+
+    def _set_permissions(self, file_name, perms):
+        os.chmod(file_name, perms)
+        if os.geteuid() == 0:
+            os.chown(file_name, self.use_keystone_user or -1,
+                     self.use_keystone_group or -1)
 
     def exec_command(self, command):
         to_exec = command % self.ssl_dictionary
-        print (to_exec)
-        subprocess.check_call(to_exec.rsplit(" "))
+        LOG.info(to_exec)
+        subprocess.check_call(to_exec.rsplit(' '))
 
     def build_ssl_config_file(self):
         if not file_exists(self.ssl_config_file_name):
-            make_dirs(self.ssl_config_file_name)
+            self._make_dirs(self.ssl_config_file_name)
             ssl_config_file = open(self.ssl_config_file_name, 'w')
             ssl_config_file.write(self.sslconfig % self.ssl_dictionary)
             ssl_config_file.close()
-        os.chmod(self.ssl_config_file_name, CERT_PERMS)
+        self._set_permissions(self.ssl_config_file_name, CERT_PERMS)
 
-        index_file_name = os.path.join(self.conf_dir, "index.txt")
+        index_file_name = os.path.join(self.conf_dir, 'index.txt')
         if not file_exists(index_file_name):
             index_file = open(index_file_name, 'w')
-            index_file.write("")
+            index_file.write('')
             index_file.close()
-        os.chmod(self.ssl_config_file_name, PRIV_PERMS)
+        self._set_permissions(self.ssl_config_file_name, PRIV_PERMS)
 
-        serial_file_name = os.path.join(self.conf_dir, "serial")
+        serial_file_name = os.path.join(self.conf_dir, 'serial')
         if not file_exists(serial_file_name):
             index_file = open(serial_file_name, 'w')
-            index_file.write("01")
+            index_file.write('01')
             index_file.close()
-        os.chmod(self.ssl_config_file_name, PRIV_PERMS)
+        self._set_permissions(self.ssl_config_file_name, PRIV_PERMS)
 
     def build_ca_cert(self):
         if not file_exists(CONF.signing.ca_certs):
             if not os.path.exists(self.ca_key_file):
-                make_dirs(self.ca_key_file)
-                self.exec_command("openssl genrsa -out %(ca_private_key)s "
-                                  "%(key_size)d -config %(ssl_config)s")
-                os.chmod(self.ssl_dictionary["ca_private_key"], stat.S_IRUSR)
-            print("Generating CA certificate")
+                self._make_dirs(self.ca_key_file)
+                self.exec_command('openssl genrsa -out %(ca_private_key)s '
+                                  '%(key_size)d -config %(ssl_config)s')
+                self._set_permissions(self.ssl_dictionary['ca_private_key'],
+                                      stat.S_IRUSR)
             self.exec_command('openssl req -new -x509 -extensions v3_ca '
                               '-passin pass:%(ca_password)s '
                               '-key %(ca_private_key)s -out %(ca_cert)s '
                               '-days %(valid_days)d '
                               '-config %(ssl_config)s '
                               '-subj %(default_subject)s')
-            os.chmod(self.ssl_dictionary["ca_cert"], CERT_PERMS)
+            self._set_permissions(self.ssl_dictionary['ca_cert'], CERT_PERMS)
 
     def build_private_key(self):
-        if not file_exists(CONF.signing.keyfile):
-            make_dirs(CONF.signing.keyfile)
+        signing_keyfile = self.ssl_dictionary['signing_key']
 
-            self.exec_command("openssl genrsa -out %(signing_key)s "
-                              "%(key_size)d "
-                              "-config %(ssl_config)s")
-        os.chmod(os.path.dirname(self.ssl_dictionary["signing_key"]),
-                 PRIV_PERMS)
-        os.chmod(self.ssl_dictionary["signing_key"], stat.S_IRUSR)
+        if not file_exists(signing_keyfile):
+            self._make_dirs(signing_keyfile)
+
+            self.exec_command('openssl genrsa -out %(signing_key)s '
+                              '%(key_size)d '
+                              '-config %(ssl_config)s')
+        self._set_permissions(os.path.dirname(signing_keyfile), PRIV_PERMS)
+        self._set_permissions(signing_keyfile, stat.S_IRUSR)
 
     def build_signing_cert(self):
         if not file_exists(CONF.signing.certfile):
-            make_dirs(CONF.signing.certfile)
-            self.exec_command("openssl req -key %(signing_key)s -new -nodes "
-                              "-out %(request_file)s -config %(ssl_config)s "
-                              "-subj %(default_subject)s")
-            self.exec_command("openssl ca -batch -out %(signing_cert)s "
-                              "-config %(ssl_config)s "
-                              "-infiles %(request_file)s")
+            self._make_dirs(CONF.signing.certfile)
+            self.exec_command('openssl req -key %(signing_key)s -new -nodes '
+                              '-out %(request_file)s -config %(ssl_config)s '
+                              '-subj %(default_subject)s')
+            self.exec_command('openssl ca -batch -out %(signing_cert)s '
+                              '-config %(ssl_config)s '
+                              '-infiles %(request_file)s')
 
     def run(self):
         self.build_ssl_config_file()
