@@ -14,13 +14,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import uuid
+import nose.exc
 
 from keystone import catalog
 from keystone.catalog.backends import kvs as catalog_kvs
 from keystone import exception
-from keystone.identity.backends import kvs as identity_kvs
+from keystone import identity
 from keystone import test
 from keystone.token.backends import kvs as token_kvs
+from keystone.trust.backends import kvs as trust_kvs
 
 import default_fixtures
 import test_backend
@@ -29,9 +31,43 @@ import test_backend
 class KvsIdentity(test.TestCase, test_backend.IdentityTests):
     def setUp(self):
         super(KvsIdentity, self).setUp()
-        self.identity_api = identity_kvs.Identity(db={})
+        identity.CONF.identity.driver = \
+            'keystone.identity.backends.kvs.Identity'
+        self.identity_man = identity.Manager()
+        self.identity_api = self.identity_man.driver
         self.load_fixtures(default_fixtures)
 
+    def test_list_user_projects(self):
+        # NOTE(chungg): not implemented
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_create_duplicate_group_name_in_different_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_create_duplicate_user_name_in_different_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_create_duplicate_project_name_in_different_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_user_between_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_user_between_domains_with_clashing_names_fails(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_group_between_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_group_between_domains_with_clashing_names_fails(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_project_between_domains(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
+    def test_move_project_between_domains_with_clashing_names_fails(self):
+        raise nose.exc.SkipTest('Blocked by bug 1119770')
+
 
 class KvsToken(test.TestCase, test_backend.TokenTests):
     def setUp(self):
@@ -39,6 +75,18 @@ class KvsToken(test.TestCase, test_backend.TokenTests):
         self.token_api = token_kvs.Token(db={})
 
 
+class KvsTrust(test.TestCase, test_backend.TrustTests):
+    def setUp(self):
+        super(KvsTrust, self).setUp()
+        identity.CONF.identity.driver = \
+            'keystone.identity.backends.kvs.Identity'
+        self.identity_man = identity.Manager()
+        self.identity_api = self.identity_man.driver
+        self.trust_api = trust_kvs.Trust(db={})
+        self.catalog_api = catalog_kvs.Catalog(db={})
+        self.load_fixtures(default_fixtures)
+
+
 class KvsCatalog(test.TestCase, test_backend.CatalogTests):
     def setUp(self):
         super(KvsCatalog, self).setUp()
@@ -54,7 +102,7 @@ class KvsCatalog(test.TestCase, test_backend.CatalogTests):
 
     def test_get_catalog_404(self):
         # FIXME(dolph): this test should be moved up to test_backend
-        # FIXME(dolph): exceptions should be UserNotFound and TenantNotFound
+        # FIXME(dolph): exceptions should be UserNotFound and ProjectNotFound
         self.assertRaises(exception.NotFound,
                           self.catalog_api.get_catalog,
                           uuid.uuid4().hex,
@@ -68,19 +116,3 @@ class KvsCatalog(test.TestCase, test_backend.CatalogTests):
     def test_get_catalog(self):
         catalog_ref = self.catalog_api.get_catalog('foo', 'bar')
         self.assertDictEqual(catalog_ref, self.catalog_foobar)
-
-    def test_create_endpoint_404(self):
-        self.assertRaises(exception.NotImplemented,
-                          self.catalog_api.create_endpoint,
-                          uuid.uuid4().hex,
-                          {})
-
-    def test_get_endpoint_404(self):
-        self.assertRaises(exception.NotImplemented,
-                          self.catalog_api.get_endpoint,
-                          uuid.uuid4().hex)
-
-    def test_delete_endpoint_404(self):
-        self.assertRaises(exception.NotImplemented,
-                          self.catalog_api.delete_endpoint,
-                          uuid.uuid4().hex)
